/*
 * This example sketch shows how you can manage the nRF5 pin mapping as part of your code.
 * You can use the method for any nRF51822 or nRF52832 board or module.
 * 
 * Most components, like UART, SPI, Wire Bus, of the nRF5 series chips don't
 * have a fixed pin mapping. There are some pins with restrictions like analog
 * inputs, NFC or pins near the radio module. Please refer the latest
 * documentation about pin restrictions at http://infocenter.nordicsemi.com 
 * 
 * To use the custom pin mapping you have to do following steps:
 * 
 * 1. Install "arduino-nrf5" like described at
 *    https://github.com/sandeepmistry/arduino-nRF5/
 * 2. Install the "My Sensors nRF5 Boards" with the board manager like
 *    explained at https://github.com/mysensors/ArduinoBoards
 * 3. Copy the files "MyNRF5Board.cpp" and "MyNRF5Board.h" from
 *    "MyNRF5Board" example into your sketch.
 * 4. Modify pin mappings in "MyNRF5Board.cpp" and "MyNRF5Board.h" to fit
 *    your requirements.
 * 5. Select "MyNRF5Board nrf52832" or "MyNRF5Board nrf52822" as your board.
 *    Choose the correct parameters and programmer in the Tools menu.
 */

//Simple program to demonstrate that Serial is working correctly on the breakout board:
// https://www.openhardware.io/view/443/nRF52832-ESP-LINK-Shield-for-ESP8266-Wemos-D1-Mini
//Note: Compile and upload from Arduino IDE using "MyNRF5Board nRF52832" as the board.  
// Under the Tools menu, be sure to set Reset: Enable.
//
// Many thanks to d00616 for this framework!

#include <nrf.h>
#include <MySensors.h>

void setup() {
  Serial.begin(460800);
  Serial.println();
  Serial.println("Countdown 3...");
  Serial.flush();
  delay(100);
  Serial.println("Countdown 2...");
  Serial.flush();
  delay(100);
  Serial.println("Countdown 1...");
  Serial.flush();
  delay(100);
  Serial.println("Starting...");
  Serial.flush();
  delay(100);
}

uint32_t loopCounter=0;
void loop() {
  Serial.println(loopCounter++);
  Serial.flush();
}
